@@ -8,7 +8,8 @@ from inforion.ionapi.controller import *
 from inforion.ionapi.model import *
 from inforion.transformation.transform import parallelize_tranformation
 
-# from inforion.ionapi.ionbasic import ionbasic
+import logging
+#from logger import get_logger
 
 # from ionbasic import load_config
 
@@ -27,10 +28,12 @@ def main_load(
 ):
 
     if validators.url(url) != True:
-        return "Error: URL is not valid"
-
+        logging.info("Error: URL is not valid")
+        return ("Error: URL is not valid")
+    
     if os.path.exists(ionfile) == False:
-        return "Error: File does not exist"
+        logging.info("Error: File does not exist")
+        return ("Error: File does not exist")
     else:
         inforlogin.load_config(ionfile)
 
