@@ -7,6 +7,7 @@ import inforion as infor
 from inforion.datacatalog.datacatalog import delete_datacatalog_object
 from inforion.datacatalog.datacatalog import ObjectSchemaType
 from inforion.datacatalog.datacatalog import post_datacatalog_object
+from inforion.datalake.datalake import delete_v1_purge_filter
 from inforion.datalake.datalake import delete_v1_purge_id
 from inforion.datalake.datalake import get_v1_payloads_list
 from inforion.datalake.datalake import get_v1_payloads_stream_by_id
@@ -14,6 +15,21 @@ from inforion.excelexport import *
 from inforion.helper.filehandling import *
 from inforion.ionapi.controller import *
 from inforion.ionapi.model import *
+import inforion.ln as lni
+
+import logging
+import os.path
+import os
+
+import logging
+#from logger import get_logger
+
+from inforion.datacatalog.datacatalog import (
+    post_datacatalog_object,
+    delete_datacatalog_object,
+    ObjectSchemaType,
+)
+from inforion.messaging.messaging import post_messaging_v2_multipart_message
 from inforion.ionapi.model import inforlogin
 from inforion.messaging.messaging import post_messaging_v2_multipart_message
 
@@ -111,7 +127,7 @@ def load(
                 inputfile = config_json["inputfile"]
                 outputfile = config_json["outputfile"]
             else:
-                print("JSON File wrong config")
+                logging.error("JSON File wrong config")
                 sys.exit(0)
             if "start" in config_json:
                 start = config_json["start"]
@@ -138,9 +154,9 @@ def load(
 def extract(program, outputfile):
 
     if not "program" in locals() or not program:
-        print("\033[91m" + "Error: Program name is missing" + "\033[0m")
+        logging.info("\033[91m" + "Error: Program name is missing" + "\033[0m")
     if not "outputfile" in locals() or not outputfile:
-        print("\033[91m" + "Error: Output filename is missing" + "\033[0m")
+        logging.info("\033[91m" + "Error: Output filename is missing" + "\033[0m")
 
     if program and outputfile:
         generate_api_template_file(program, outputfile)
@@ -250,6 +266,15 @@ def upload(ionfile, schema, logical_id, file):
 @click.option("--page", "-p", help="Please define the page")
 @click.option("--records", "-r", help="Please define the records")
 def datalake_list(ionfile, list_filter=None, sort=None, page=None, records=None):
+    """
+    List data object properties using a filter.
+    :param ionfile: Infor IONAPI credentials file.
+    :param list_filter: The restrictions to be applied on the returned records.
+    :param sort: Field name followed by colon followed by direction (asc or desc; default asc).
+    Example: 'event_date:desc'.
+    :param page: The page number from which to start returning records. Starts from 1.
+    :param records: The number of records that will be returned. Starts from 0
+    """
     inforlogin.load_config(ionfile)
     inforlogin.login()
     response = get_v1_payloads_list(list_filter, sort, page, records)
@@ -263,22 +288,46 @@ def datalake_list(ionfile, list_filter=None, sort=None, page=None, records=None)
 @datalake.command(name="purge", help="Datalake purge")
 @click.option("--ionfile", "-i", help="Please define the ionfile file")
 @click.option("--ids", "-id", help="Please define the ids")
-def datalake_purge(ionfile, ids):
+@click.option("--purge_filter", "-f", help="Please define the filter")
+def datalake_purge(ionfile, ids, purge_filter):
+    """
+    Deletes Data Objects based on the given filter or a list of IDs.
+    You cannot define both arguments: ids and purge_filter.
+    :param ionfile: Infor IONAPI credentials file.
+    :param ids: Object ids.
+    :param purge_filter: The restrictions to be applied to purge the records
+    """
+    if ids is not None and purge_filter is not None:
+        raise ValueError("You cannot define both arguments: ids and purge_filter.")
+
     inforlogin.load_config(ionfile)
     inforlogin.login()
-    ids_list = ids.split(",")
-    response = delete_v1_purge_id(ids_list)
 
-    if response.status_code == 200:
-        click.echo(response.text)
-    else:
-        logger.error(response.content)
+    if ids is not None:
+        ids_list = ids.split(",")
+        response = delete_v1_purge_id(ids_list)
+        if response.status_code == 200:
+            click.echo(response.text)
+        else:
+            logger.error(response.content)
+
+    if purge_filter is not None:
+        response = delete_v1_purge_filter(purge_filter)
+        if response.status_code == 200:
+            click.echo(response.text)
+        else:
+            logger.error(response.content)
 
 
 @datalake.command(name="get", help="Datalake get")
 @click.option("--ionfile", "-i", help="Please define the ionfile file")
 @click.option("--stream_id", "-id", help="Please define the id")
 def datalake_get(ionfile, stream_id):
+    """
+    Retrieve payload based on id from datalake.
+    :param ionfile: Infor IONAPI credentials file.
+    :param stream_id: Object ID.
+    """
     inforlogin.load_config(ionfile)
     inforlogin.login()
     response = get_v1_payloads_stream_by_id(stream_id)
@@ -289,9 +338,44 @@ def datalake_get(ionfile, stream_id):
         logger.error(response.content)
 
 
+@main.group(name="check")
+def check():
+    """Commands to check soemthing"""
+    pass
+
+
+@check.command(name="Check_Token", help="Check Login Token")
+@click.option("--url", "-u", help="URL to local ION")
+@click.option("--ionfile", "-i", help="Please define the ionfile file")
+def check_token(url, ionfile):
+    """Check Login and display the token"""
+    inforlogin.load_config(ionfile)
+    inforlogin.login()
+
+
+@main.group(name="ln")
+def ln():
+    """Commands related to Export Data from LN."""
+    pass
+
+
+@ln.command(name="ExportData", help="Export Data")
+@click.option("--url", "-u", help="URL to local ION")
+@click.option("--ionfile", "-i", help="Please define the ionfile file")
+@click.option("--company", "-c", help="Company for which we need to export")
+@click.option("--service_name", "-s", help="Service name. e.g. BusinessPartner, SalesOrder")
+@click.option("--outputfile", "-o", help="File as Output File")
+def export_data(url, ionfile, company, service_name, outputfile):
+    """Exports business partner to an Excel file"""
+
+    inforlogin.load_config(ionfile)
+    token = inforlogin.login()['access_token']
+    lni.export_data(url, token, company, service_name, outputfile)
+
 main.add_command(load)
 main.add_command(transform)
 main.add_command(extract)
+main.add_command(check)
 
 if __name__ == "__main__":
     main()
